==> hub_rest_client-0.1.1-py3-none-any.whl: hub_rest_client/api/default/get_users_user_id_sshpublickeys_ssh_public_key_id.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.ssh_public_key import SshPublicKey
from ...types import UNSET, Response, Unset


def _get_kwargs(
    user_id: str,
    ssh_public_key_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "fingerPrint,data,openSshKey,comment",
) -> Dict[str, Any]:
    url = "{}/users/{userId}/sshpublickeys/{sshPublicKeyId}".format(
        client.hub_base_url, userId=user_id, sshPublicKeyId=ssh_public_key_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[SshPublicKey]:
    if response.status_code == 200:
        response_200 = SshPublicKey.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[SshPublicKey]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    user_id: str,
    ssh_public_key_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "fingerPrint,data,openSshKey,comment",
) -> Response[SshPublicKey]:
    kwargs = _get_kwargs(
        user_id=user_id,
        ssh_public_key_id=ssh_public_key_id,
        client=client,
        fields=fields,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    user_id: str,
    ssh_public_key_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "fingerPrint,data,openSshKey,comment",
) -> Optional[SshPublicKey]:
    """ """

    return sync_detailed(
        user_id=user_id,
        ssh_public_key_id=ssh_public_key_id,
        client=client,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    user_id: str,
    ssh_public_key_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "fingerPrint,data,openSshKey,comment",
) -> Response[SshPublicKey]:
    kwargs = _get_kwargs(
        user_id=user_id,
        ssh_public_key_id=ssh_public_key_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    user_id: str,
    ssh_public_key_id: str,
    *,
    client: AuthenticatedClient,
    fields: Union[Unset, None, str] = "fingerPrint,data,openSshKey,comment",
) -> Optional[SshPublicKey]:
    """ """

    return (
        await asyncio_detailed(
            user_id=user_id,
            ssh_public_key_id=ssh_public_key_id,
            client=client,
            fields=fields,
        )
    ).parsed

==> hub_rest_client-0.1.2-py3-none-any.whl: hub_rest_client/api/default/get_users_user_id_sshpublickeys_ssh_public_key_id.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models import ssh_public_key as ssh_public_key_m
from ...types import UNSET, Response, Unset


def _get_kwargs(
    user_id: "str",
    ssh_public_key_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "fingerPrint,data,openSshKey,comment",
) -> Dict[str, Any]:
    url = "{}/users/{userId}/sshpublickeys/{sshPublicKeyId}".format(
        client.hub_base_url, userId=user_id, sshPublicKeyId=ssh_public_key_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[ssh_public_key_m.SshPublicKey]:
    if response.status_code == 200:
        response_200 = ssh_public_key_m.SshPublicKey.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[ssh_public_key_m.SshPublicKey]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    user_id: "str",
    ssh_public_key_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "fingerPrint,data,openSshKey,comment",
) -> Response[ssh_public_key_m.SshPublicKey]:
    kwargs = _get_kwargs(
        user_id=user_id,
        ssh_public_key_id=ssh_public_key_id,
        client=client,
        fields=fields,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    user_id: "str",
    ssh_public_key_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "fingerPrint,data,openSshKey,comment",
) -> Optional[ssh_public_key_m.SshPublicKey]:
    """ """

    return sync_detailed(
        user_id=user_id,
        ssh_public_key_id=ssh_public_key_id,
        client=client,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    user_id: "str",
    ssh_public_key_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "fingerPrint,data,openSshKey,comment",
) -> Response[ssh_public_key_m.SshPublicKey]:
    kwargs = _get_kwargs(
        user_id=user_id,
        ssh_public_key_id=ssh_public_key_id,
        client=client,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    user_id: "str",
    ssh_public_key_id: "str",
    *,
    client: AuthenticatedClient,
    fields: "Union[Unset, None, str]" = "fingerPrint,data,openSshKey,comment",
) -> Optional[ssh_public_key_m.SshPublicKey]:
    """ """

    return (
        await asyncio_detailed(
            user_id=user_id,
            ssh_public_key_id=ssh_public_key_id,
            client=client,
            fields=fields,
        )
    ).parsed
